wine/dlls/shell32 shlview.c

Alexandre Julliard julliard at wine.codeweavers.com
Mon Nov 28 14:04:18 CST 2005


ChangeSet ID:	21501
CVSROOT:	/opt/cvs-commit
Module name:	wine
Changes by:	julliard at winehq.org	2005/11/28 14:04:18

Modified files:
	dlls/shell32   : shlview.c 

Log message:
	Michael Jung <mjung at iss.tu-darmstadt.de>
	Use GetUIObjectOf instead of BindToObject to get a IDropTarget object.

Patch: http://cvs.winehq.org/patch.py?id=21501

Old revision  New revision  Changes     Path
 1.121         1.122         +3 -3       wine/dlls/shell32/shlview.c

Index: wine/dlls/shell32/shlview.c
diff -u -p wine/dlls/shell32/shlview.c:1.121 wine/dlls/shell32/shlview.c:1.122
--- wine/dlls/shell32/shlview.c:1.121	28 Nov 2005 20: 4:18 -0000
+++ wine/dlls/shell32/shlview.c	28 Nov 2005 20: 4:18 -0000
@@ -2223,9 +2223,9 @@ static HRESULT drag_notify_subitem(IShel
         lvItem.iItem = lResult;
         ListView_GetItemA(This->hWndList, &lvItem);
 
-        /* ... and bind pCurDropTarget to this folder's IDropTarget interface */
-        hr = IShellFolder_BindToObject(This->pSFParent, (LPITEMIDLIST)lvItem.lParam, NULL, 
-                                       &IID_IDropTarget, (LPVOID*)&This->pCurDropTarget);
+        /* ... and bind pCurDropTarget to the IDropTarget interface of an UIObject of this object */
+        hr = IShellFolder_GetUIObjectOf(This->pSFParent, This->hWndList, 1,
+            (LPCITEMIDLIST*)&lvItem.lParam, &IID_IDropTarget, NULL, (LPVOID*)&This->pCurDropTarget);
     }
 
     /* If anything failed, pCurDropTarget should be NULL now, which ought to be a save state. */



More information about the wine-cvs mailing list